@@ -29,11 +29,9 @@ def toUnicode(objekt):
     @param objekt: anything
     @return: the object itself if not a string, otherwise the unicode of the string
     """
-
     if not isinstance(objekt, str):
         return objekt
-    return unicode(objekt, 'ascii')
-
+    return unicode(objekt, 'utf-8')
 
 
 class IndexableTextExtractor(object):
@@ -46,7 +44,6 @@ class IndexableTextExtractor(object):
         @param content_type: content_type of the part for which the extractor is defined
         @param text_elements: default text elements. See self.addTextElement(...)
         """
-
         self.content_type = content_type
         self.text_elts_xpaths = []
         for te in text_elements:
@@ -59,27 +56,23 @@ class IndexableTextExtractor(object):
         @param element_name: an element that contains text to extract.
         the name may be prefixed with a key from namespaces.ns_map
         """
-
         self.text_elts_xpaths.append(etree.XPath('//' + element_name, namespaces=ns_map))
         return
 
 
     def indexableText(self, tree):
         """Provides the indexable - search engine oriented - raw text
-        @param tree: an ElementTreee
-        @return: set(["foo", "bar", ...])"
+        @param tree: an ElementTree
+        @return: set(["foo", "bar", ...])
         """
-
         rval = set()
         root = tree.getroot()
         for txp in self.text_elts_xpaths:
             elts = txp(root)
-            texts = [self.text_extract_xpath(elt) for elt in elts]
+            texts = ''.join([self.text_extract_xpath(elt)[0] for elt in elts])
             # Texts in element may be empty
-            texts = [toUnicode(x)[0] for x in texts
+            texts = [toUnicode(x) for x in self.wordssearch_rx.findall(texts)
                      if len(x) > 0]
-            for text in texts:
-                words = self.wordssearch_rx.findall(text)
-                rval |= set(words)
+            rval |= set(texts)
         return rval
 
